# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-CPAN-Meta-Requirements
Summary:	A set of version requirements for a CPAN dist
Version:	2.143
Release:	1.%{__distinit}%{__distvers}
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/CPAN-Meta-Requirements
Source0:	https://cpan.metacpan.org/modules/by-module/CPAN/CPAN-Meta-Requirements-%{version}.tar.gz
BuildArch:	noarch
# Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(:VERSION) >= 5.10
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module
BuildRequires:	perl(B)
BuildRequires:	perl(Carp)
BuildRequires:	perl(strict)
BuildRequires:	perl(version) >= 0.88
BuildRequires:	perl(warnings)
# Test
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(Test::More) >= 0.88
# Extra/Optional Tests (not run when bootstrapping due to circular build dependencies)
%if 0%{!?perl_bootstrap:1}
%if 0%{?fedora} > 23 || 0%{?rhel} > 7
BuildRequires:	glibc-langpack-en
%endif
BuildRequires:	perl(blib)
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(IPC::Open3)
BuildRequires:	perl(Perl::Critic::Policy::Lax::ProhibitStringyEval::ExceptForRequire)
BuildRequires:	perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
BuildRequires:	perl(Pod::Coverage::TrustPod)
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::CPAN::Meta)
BuildRequires:	perl(Test::MinimumVersion)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.41
BuildRequires:	perl(Test::Pod::Coverage) >= 1.08
BuildRequires:	perl(Test::Portability::Files)
BuildRequires:	perl(Test::Spelling) >= 0.12, hunspell-en
BuildRequires:	perl(Test::Version) >= 1
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(B)
Requires:	perl(version) >= 0.88

# Had a six-digit version in a previous life
%global six_digit_version %(LC_ALL=C; printf '%.6f' '%{version}')

# Provide the six-digit version of the module
%if "%{version}" != "%{six_digit_version}"
Provides:	perl(CPAN::Meta::Requirements) = %{six_digit_version}
%global __provides_exclude ^perl\\(CPAN::Meta::Requirements\\)
%endif

%description
A CPAN::Meta::Requirements object models a set of version constraints like
those specified in the META.yml or META.json files in CPAN distributions. It
can be built up by adding more and more constraints, and it will reduce them
to the simplest representation.

Logically impossible constraints will be identified immediately by thrown
exceptions.

%prep
%setup -q -n CPAN-Meta-Requirements-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor UNINST=0
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test AUTHOR_TESTING=1
%if 0%{!?perl_bootstrap:1}
LANG=en_US make test TEST_FILES="$(echo $(find xt/ -name '*.t'))"
%endif

%files
%license LICENSE
%doc Changes CONTRIBUTING.mkdn README
%{perl_vendorlib}/CPAN/
%{_mandir}/man3/CPAN::Meta::Requirements.3*
%{_mandir}/man3/CPAN::Meta::Requirements::Range.3*

%changelog
* Tue Jun 20 2023 Paul Howarth <paul@city-fan.org> - 2.143-1
- Update to 2.143
  - Fix regression with implicit minimum value and multiple requirements (GH#38)

* Wed May 31 2023 Paul Howarth <paul@city-fan.org> - 2.142-2
- Fix regression with multiple version numbers
  (rhbz#2208279, GH#38)

* Tue May  9 2023 Paul Howarth <paul@city-fan.org> - 2.142-1
- Update to 2.142
  - confess() replaced with croak(): fewer stack traces
  - Broke the version range handling into the Range class
  - Note: this version now requires perl v5.10 rather than v5.6
- Use author-independent source URL

* Thu Mar  9 2023 Paul Howarth <paul@city-fan.org> - 2.140-491
- Use SPDX-format license tag
- Use %%license unconditionally
- Drop support for building with rpm < 4.9
- Use hunspell dictionary rather than aspell dictionary in tests

* Fri Mar  8 2019 Paul Howarth <paul@city-fan.org> - 2.140-419
- Work around mock locale issues by adding buildreq glibc-langpack-en when
  running extra tests

* Wed Jun 27 2018 Paul Howarth <paul@city-fan.org> - 2.140-416
- Perl 5.28 rebuild

* Thu Apr  6 2017 Paul Howarth <paul@city-fan.org> - 2.140-7
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Mon Aug  1 2016 Paul Howarth <paul@city-fan.org> - 2.140-5
- Fix FTBFS when perl is not in the minimal buildroot
- BR: perl-generators where available
- Simplify find command using -delete
- Prefer %%global over %%define

* Mon Dec 14 2015 Paul Howarth <paul@city-fan.org> - 2.140-1
- Update to 2.140
  - Added method for getting structured requirements
  - Skips impossible tests on Perls earlier than 5.8.0 (before v-string magic)
  - On Perls before 5.8.1, pad 1-part and 2-part literal v-strings to avoid old
    version.pm bugs with v-strings less than 3 characters
  - Protect internal _isa_version from non-refs that pass ->isa('version')
  - Much better error messages, explaining what conflicted and how
  - Repackage with fixed tests
  - Expanded dist.ini from author bundle to individual plugins
- Update patch for building with Test::More < 0.88

* Tue Jun 23 2015 Paul Howarth <paul@city-fan.org> - 2.133-4
- Perl 5.22 rebuild

* Sun Feb 22 2015 Paul Howarth <paul@city-fan.org> - 2.133-1
- Update to 2.133
  - In fixing preservation of "0.00", some Module => 0 optimizations were lost;
    this restores those optimizations

* Fri Jan 23 2015 Paul Howarth <paul@city-fan.org> - 2.132-1
- Update to 2.132
  - Precision of version requirement "0.00" is preserved when merging
    requirements
- Update patch for building with Test::More < 0.88

* Wed Dec 24 2014 Paul Howarth <paul@city-fan.org> - 2.131-1
- Update to 2.131
  - Merging Module => 0 into requirements is now optimized
  - Scalar::Utils removed as a prerequisite
- Update patch for building with Test::More < 0.88

* Thu Nov 20 2014 Paul Howarth <paul@city-fan.org> - 2.130-1
- Update to 2.130
  - from_string_hash can take optional constructor arguments
  - bad_version_hook callback gets module name as well as version string
  - undefined/empty versions given to from_string_hash or
    add_string_requirement now carp and are coerced to "0" instead of being
    fatal; this is more consistent with how the other requirement functions
    work
- Update patch for building with Test::More < 0.88

* Fri Nov 14 2014 Paul Howarth <paul@city-fan.org> - 2.129-1
- Update to 2.129
  - from_string_hash can now accept v-strings as hash values
- Update patch for building with Test::More < 0.88
- Can always run xt/author/00-compile.t now

* Thu Oct  2 2014 Paul Howarth <paul@city-fan.org> - 2.128-2
- Add explicit dependency on perl(version)

* Mon Sep 22 2014 Paul Howarth <paul@city-fan.org> - 2.128-1
- Update to 2.128
  - Works around limitations in version::vpp detecting v-string magic
  - Requires version.pm 0.88 in metadata, but code should work with any version
    of version.pm
  - Adds support for forthcoming ExtUtils::MakeMaker bootstrap version.pm for
    Perls older than 5.10.0
  - Throws an error at compile time if neither version nor the
    ExtUtils::MakeMaker bootstrap are available
- Update patch for building with Test::More < 0.88
- Don't bother with xt/author/00-compile.t if we have Test::More < 0.82

* Sun Aug 17 2014 Paul Howarth <paul@city-fan.org> - 2.126-2
- Don't BR: perl(CPAN::Meta) when bootstrapping

* Thu Jul 31 2014 Paul Howarth <paul@city-fan.org> - 2.126-1
- Update to 2.126
  - Fixed compatibility with version.pm 0.77
  - Minor documentation fixes
  - Modernized distribution meta files
- Use %%license where possible
- Drop %%defattr, redundant since rpm 4.4

* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 2.125-1
- Update to 2.125
  - Updated Makefile.PL logic to support PERL_NO_HIGHLANDER

* Mon Sep 23 2013 Paul Howarth <paul@city-fan.org> - 2.124-1
- Update to 2.124
  - Better fix than 2.123: on old perls, rather than install into 'core', we
    continue to install into the proper 'site' library, but force UNINST=1 when
    necessary to remove stale copies from ExtUtils::MakeMaker

* Sat Aug 31 2013 Paul Howarth <paul@city-fan.org> - 2.123-1
- Update to 2.123
  - On Perls prior to v5.12, CPAN::Meta::Requirements will be installed into
    the 'core' library path to avoid an older version bundled with
    ExtUtils::MakeMaker and installed there taking precedence
- Drop now-redundant buildreq perl(Test::Requires) and associated patch
- Add new buildreqs for tests: perl(File::Spec::Functions), perl(IO::Handle),
  perl(IPC::Open3), perl(List::Util) and perl(Test::MinimumVersion)
- Run test suite with AUTHOR_TESTING=1 for additional coverage

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 2.122-290
- Perl 5.18 rebuild

* Thu Aug 23 2012 Paul Howarth <paul@city-fan.org> - 2.122-5
- Don't run extra tests when bootstrapping

* Sat Jul 14 2012 Paul Howarth <paul@city-fan.org> - 2.122-4
- Drop BR: perl(File::Find), not dual-lived
- BR: perl(English)
- BR: perl(Perl::Critic::Policy::Miscellanea::RequireRcsKeywords)
- Specify version requirements for perl(Test::Pod), perl(Test::Pod::Coverage)
  and perl(Test::Spelling)

* Thu May  3 2012 Paul Howarth <paul@city-fan.org> - 2.122-1
- Update to 2.122
  - Fix typo in documentation: the exclusion symbol is "!=" rather than just
    "!"; the implementation was correct, just the docs were wrong
   (CPAN RT#76948)
- Update patches as necessary

* Tue Apr  3 2012 Paul Howarth <paul@city-fan.org> - 2.121-3
- Provide six-digit version number of module

* Sun Apr  1 2012 Paul Howarth <paul@city-fan.org> - 2.121-1
- Initial RPM version, split from perl-CPAN-Meta
